@@ -17,15 +17,14 @@ import os
 import optparse
 import ConfigParser
 import bottle
-from healthgraph import RunKeeperAuthMgr, RunKeeperClient
+import healthgraph
 from beaker.middleware import SessionMiddleware
 
-
 __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2012, Ali Onur Uyar"
 __credits__ = []
 __license__ = "GPL"
-__version__ = "0.2.2"
+__version__ = "0.3.0"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -60,10 +59,10 @@ def index():
     if sess.has_key('rk_access_token'):
         bottle.redirect('/welcome')
     else:
-        rk_auth_mgr = RunKeeperAuthMgr(conf['client_id'], conf['client_secret'], 
-                                       '/'.join((conf['baseurl'], 'login',)))
-        rk_auth_uri = rk_auth_mgr.getLoginURL()
-        rk_button_img = rk_auth_mgr.getLoginButtonURL('blue', 'black', 300)
+        rk_auth_mgr = healthgraph.AuthManager(conf['client_id'], conf['client_secret'], 
+                                          '/'.join((conf['baseurl'], 'login',)))
+        rk_auth_uri = rk_auth_mgr.get_login_url()
+        rk_button_img = rk_auth_mgr.get_login_button_url('blue', 'black', 300)
         return bottle.template('index.html', {'rk_button_img': rk_button_img,
                                               'rk_auth_uri': rk_auth_uri,})
         
@@ -72,9 +71,9 @@ def login():
     sess = bottle.request.environ['beaker.session']
     code = bottle.request.query.get('code')
     if code is not None:
-        rk_auth_mgr = RunKeeperAuthMgr(conf['client_id'], conf['client_secret'], 
-                                       '/'.join((conf['baseurl'], 'login',)))
-        access_token = rk_auth_mgr.getAccessToken(code)
+        rk_auth_mgr = healthgraph.AuthManager(conf['client_id'], conf['client_secret'], 
+                                              '/'.join((conf['baseurl'], 'login',)))
+        access_token = rk_auth_mgr.get_access_token(code)
         sess['rk_access_token'] = access_token
         sess.save()
         bottle.redirect('/welcome')
@@ -84,14 +83,15 @@ def welcome():
     sess = bottle.request.environ['beaker.session']
     access_token = sess.get('rk_access_token')
     if access_token is not None:
-        rk = RunKeeperClient(access_token)
-        profile = rk.getProfile()
-        records = rk.getRecords()
-        activities = rk.getActivityList(5)
+        user = healthgraph.User(session=healthgraph.Session(access_token))
+        profile = user.get_profile()
+        records = user.get_records()
+        act_iter = user.get_fitness_activity_iter()
+        activities = [act_iter.next() for _ in range(5)]
         return bottle.template('welcome.html', 
                                profile=profile,
                                activities=activities, 
-                               records=records)
+                               records=records.get_totals())
     else:
         bottle.redirect('/')
 
